diff mbox series

[v4] PCI: rcar: Check if device is runtime suspended instead of __clk_is_enabled()

Message ID 20211115204641.12941-1-marek.vasut@gmail.com
State New
Headers show
Series [v4] PCI: rcar: Check if device is runtime suspended instead of __clk_is_enabled() | expand

Commit Message

Marek Vasut Nov. 15, 2021, 8:46 p.m. UTC
From: Marek Vasut <marek.vasut+renesas@gmail.com>

Replace __clk_is_enabled() with pm_runtime_suspended(),
as __clk_is_enabled() was checking the wrong bus clock
and caused the following build error too:
  arm-linux-gnueabi-ld: drivers/pci/controller/pcie-rcar-host.o: in function `rcar_pcie_aarch32_abort_handler':
  pcie-rcar-host.c:(.text+0xdd0): undefined reference to `__clk_is_enabled'

Fixes: a115b1bd3af0 ("PCI: rcar: Add L1 link state fix into data abort hook")
Reviewed-by: Geert Uytterhoeven <geert+renesas@glider.be>
Acked-by: Randy Dunlap <rdunlap@infradead.org>
Signed-off-by: Marek Vasut <marek.vasut+renesas@gmail.com>
Cc: Arnd Bergmann <arnd@arndb.de>
Cc: Bjorn Helgaas <bhelgaas@google.com>
Cc: Geert Uytterhoeven <geert+renesas@glider.be>
Cc: Lorenzo Pieralisi <lorenzo.pieralisi@arm.com>
Cc: Stephen Boyd <sboyd@kernel.org>
Cc: Wolfram Sang <wsa@the-dreams.de>
Cc: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
Cc: linux-renesas-soc@vger.kernel.org
---
V2: Drop the __clk_is_enabled(), like it was done already in V1 of
    a115b1bd3af0 ("PCI: rcar: Add L1 link state fix into data abort hook")
V3: Use pm_runtime_suspended() instead of __clk_is_enabled()
V4: Rework the commit message
---
 drivers/pci/controller/pcie-rcar-host.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

Comments

Krzysztof WilczyƄski Nov. 15, 2021, 9:59 p.m. UTC | #1
[+CC Adding Sasha for visibility]

Hi Marek,

Thank you for taking care about this.  I am adding Sasha since this is
something we should most likely port to stable and long-term kernels,
especially since this isn't a new driver.

[...]
> - * Static copy of bus clock pointer, so we can check whether the clock
> - * is enabled or not.
> + * Static copy of pcie device pointer, so we can check whether the
> + * device is runtime suspended or not.

A small nitpick: it would be "PCIe" in the above comment.  However,
probably not worth sending another version just for this.

	Krzysztof
Lorenzo Pieralisi Dec. 1, 2021, 4:24 p.m. UTC | #2
On Mon, 15 Nov 2021 21:46:41 +0100, marek.vasut@gmail.com wrote:
> From: Marek Vasut <marek.vasut+renesas@gmail.com>
> 
> Replace __clk_is_enabled() with pm_runtime_suspended(),
> as __clk_is_enabled() was checking the wrong bus clock
> and caused the following build error too:
>   arm-linux-gnueabi-ld: drivers/pci/controller/pcie-rcar-host.o: in function `rcar_pcie_aarch32_abort_handler':
>   pcie-rcar-host.c:(.text+0xdd0): undefined reference to `__clk_is_enabled'
> 
> [...]

Applied to pci/rcar, thanks!

[1/1] PCI: rcar: Check if device is runtime suspended instead of __clk_is_enabled()
      https://git.kernel.org/lpieralisi/pci/c/d2a14b5498

Thanks,
Lorenzo
diff mbox series

Patch

diff --git a/drivers/pci/controller/pcie-rcar-host.c b/drivers/pci/controller/pcie-rcar-host.c
index e12c2d8be05a..138592e22600 100644
--- a/drivers/pci/controller/pcie-rcar-host.c
+++ b/drivers/pci/controller/pcie-rcar-host.c
@@ -50,10 +50,10 @@  struct rcar_msi {
  */
 static void __iomem *pcie_base;
 /*
  * Static copy of bus clock pointer, so we can check whether the clock
  * is enabled or not.
  */
-static struct clk *pcie_bus_clk;
+static struct device *pcie_dev;
 #endif
 
 /* Structure representing the PCIe interface */
@@ -792,7 +792,7 @@  static int rcar_pcie_get_resources(struct rcar_pcie_host *host)
 #ifdef CONFIG_ARM
 	/* Cache static copy for L1 link state fixup hook on aarch32 */
 	pcie_base = pcie->base;
-	pcie_bus_clk = host->bus_clk;
+	pcie_dev = pcie->dev;
 #endif
 
 	return 0;
@@ -1062,7 +1062,7 @@  static int rcar_pcie_aarch32_abort_handler(unsigned long addr,
 
 	spin_lock_irqsave(&pmsr_lock, flags);
 
-	if (!pcie_base || !__clk_is_enabled(pcie_bus_clk)) {
+	if (!pcie_base || pm_runtime_suspended(pcie_dev)) {
 		ret = 1;
 		goto unlock_exit;
 	}
@@ -50,10 +50,10 @@  struct rcar_msi {
 static void __iomem *pcie_base;
 /*
- * Static copy of bus clock pointer, so we can check whether the clock
- * is enabled or not.
+ * Static copy of pcie device pointer, so we can check whether the
+ * device is runtime suspended or not.
  */